from typing import Optional

import numpy
import numpy.typing

import lagrange


def mesh_from_oriented_points(points : numpy.typing.NDArray[numpy.float64], normals : numpy.typing.NDArray[numpy.float64], octree_depth : int = 0, interpolation_weight : float = 2.0, use_normal_length_as_confidence : bool = False, use_dirichlet_boundary : bool = False, colors : Optional[numpy.typing.NDArray] = None, output_vertex_depth_attribute_name : str = '', verbose : bool = False) -> lagrange.SurfaceMesh32f:
    """
    Creates a triangle mesh from an oriented point cloud using Poisson surface reconstruction.

    :param points: Input point cloud positions (N x 3 matrix).
    :param normals: Input point cloud normals (N x 3 matrix).
    :param octree_depth: Maximum octree depth. (If the value is zero then log base 4 of the point count is used.)
    :param interpolation_weight: Point interpolation weight (lambda).
    :param use_normal_length_as_confidence: Use normal length as confidence.
    :param use_dirichlet_boundary: Use Dirichlet boundary conditions.
    :param colors: Optional color attribute to interpolate (N x K matrix).
    :param output_vertex_depth_attribute_name: Output density attribute name. We use a point's target octree depth as a measure of the sampling density. A lower number means a low sampling density, and can be used to prune low-confidence regions as a post-process.
    :param verbose: Output logging information (directly printed to standard output).
    """
